server_timing v0.1.6 ServerTiming.Plug View Source
A plug to setup server_timing initial store,
and to set server-timing header.
Usage
Setup the plug in your app, is as simple as.
defmodule Router do
use Plug.Router
plug ServerTiming.Plug
end
A plug to setup server_timing initial store,
and to set server-timing header.
Setup the plug in your app, is as simple as.
defmodule Router do
use Plug.Router
plug ServerTiming.Plug
end